==> modonomicon-1.21.5-fabric-1.117.2-sources.jar: com/klikli_dev/modonomicon/networking/ClickCommandLinkMessage.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.networking;

import com.klikli_dev.modonomicon.Modonomicon;
import com.klikli_dev.modonomicon.data.BookDataManager;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_8710;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.server.MinecraftServer;

public class ClickCommandLinkMessage implements Message {

    public static final class_8710.class_9154<ClickCommandLinkMessage> TYPE = new class_8710.class_9154<>(class_2960.method_60655(Modonomicon.MOD_ID, "click_command_link"));


    public static final class_9139<class_9129, ClickCommandLinkMessage> STREAM_CODEC = class_9139.method_56435(
            class_2960.field_48267,
            (m) -> m.bookId,
            class_2960.field_48267,
            (m) -> m.commandId,
            ClickCommandLinkMessage::new
    );

    public class_2960 bookId;
    public class_2960 commandId;

    public ClickCommandLinkMessage(class_2960 bookId, class_2960 commandId) {
        this.bookId = bookId;
        this.commandId = commandId;
    }

    @Override
    public class_9154<? extends class_8710> method_56479() {
        return TYPE;
    }

    @Override
    public void onServerReceived(MinecraftServer minecraftServer, class_3222 player) {
        var book = BookDataManager.get().getBook(this.bookId);
        if (book != null) {
            var command = book.getCommand(this.commandId);
            if (command != null) {
                command.execute(player);
            }
        }
    }
}

==> modonomicon-1.21.8-fabric-1.116.0-sources.jar: com/klikli_dev/modonomicon/networking/ClickCommandLinkMessage.java <==
/*
 * SPDX-FileCopyrightText: 2022 klikli-dev
 *
 * SPDX-License-Identifier: MIT
 */

package com.klikli_dev.modonomicon.networking;

import com.klikli_dev.modonomicon.Modonomicon;
import com.klikli_dev.modonomicon.data.BookDataManager;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_8710;
import net.minecraft.class_9129;
import net.minecraft.class_9139;
import net.minecraft.server.MinecraftServer;

public class ClickCommandLinkMessage implements Message {

    public static final class_8710.class_9154<ClickCommandLinkMessage> TYPE = new class_8710.class_9154<>(class_2960.method_60655(Modonomicon.MOD_ID, "click_command_link"));


    public static final class_9139<class_9129, ClickCommandLinkMessage> STREAM_CODEC = class_9139.method_56436(
            class_2960.field_48267,
            (m) -> m.bookId,
            class_2960.field_48267,
            (m) -> m.commandId,
            class_2960.field_48267,
            (m) -> m.entryId,
            ClickCommandLinkMessage::new
    );

    public class_2960 bookId;
    public class_2960 commandId;
    public class_2960 entryId; // The entry the command is being run from

    public ClickCommandLinkMessage(class_2960 bookId, class_2960 commandId, class_2960 entryId) {
        this.bookId = bookId;
        this.commandId = commandId;
        this.entryId = entryId;
    }

    // Backwards compatibility
    public ClickCommandLinkMessage(class_2960 bookId, class_2960 commandId) {
        this(bookId, commandId, null);
    }

    @Override
    public class_9154<? extends class_8710> method_56479() {
        return TYPE;
    }

    @Override
    public void onServerReceived(MinecraftServer minecraftServer, class_3222 player) {
        var book = BookDataManager.get().getBook(this.bookId);
        if (book != null) {
            var command = book.getCommand(this.commandId);
            if (command != null) {
                // Check if the entry is allowed for this command
                if (this.entryId != null && !command.isEntryAllowed(this.entryId)) {
                    // Always use the modonomicon-defined failure message
                    player.method_64398(net.minecraft.class_2561.method_43471(
                        com.klikli_dev.modonomicon.api.ModonomiconConstants.I18n.Command.FAILURE_NOT_ALLOWED_HERE
                    ).method_27692(net.minecraft.class_124.field_1061));
                    return;
                }
                command.execute(player);
            }
        }
    }
}
